"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
class ConfigLoader {
    constructor(configClass) {
        this.cache = new Map();
        this.configClass = configClass;
    }
    flush(filename) {
        if (filename) {
            this.cache.delete(filename);
        }
        else {
            this.cache.clear();
        }
    }
    fromTarget(filename) {
        if (filename === "inline") {
            return this.configClass.empty();
        }
        if (this.cache.has(filename)) {
            return this.cache.get(filename);
        }
        let current = path.resolve(path.dirname(filename));
        let config = this.configClass.empty();
        for (;;) {
            const search = path.join(current, ".htmlvalidate.json");
            if (fs.existsSync(search)) {
                const local = this.configClass.fromFile(search);
                config = local.merge(config);
            }
            const child = current;
            current = path.dirname(current);
            if (current === child) {
                break;
            }
        }
        this.cache.set(filename, config);
        return config;
    }
}
exports.ConfigLoader = ConfigLoader;
