"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DOCUMENT_NODE_NAME = "#document";
var NodeType;
(function (NodeType) {
    NodeType[NodeType["ELEMENT_NODE"] = 1] = "ELEMENT_NODE";
    NodeType[NodeType["DOCUMENT_NODE"] = 9] = "DOCUMENT_NODE";
})(NodeType = exports.NodeType || (exports.NodeType = {}));
class DOMNode {
    constructor(nodeName, location) {
        this.location = location;
        this.nodeName = nodeName || DOCUMENT_NODE_NAME;
        this.disabledRules = new Set();
        this.nodeType = NodeType.ELEMENT_NODE;
        if (!nodeName) {
            this.nodeType = NodeType.DOCUMENT_NODE;
        }
    }
    isRootElement() {
        return this.nodeType === NodeType.DOCUMENT_NODE;
    }
    disableRule(ruleId) {
        this.disabledRules.add(ruleId);
    }
    enableRule(ruleId) {
        this.disabledRules.delete(ruleId);
    }
    ruleEnabled(ruleId) {
        return !this.disabledRules.has(ruleId);
    }
}
exports.DOMNode = DOMNode;
